Documentation
¶
Overview ¶
Package muster implements MCP tool handlers for muster bridge lifecycle management (start, stop, status).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterTools ¶
func RegisterTools(s *mcpserver.MCPServer, sc *server.ServerContext)
RegisterTools registers muster bridge lifecycle tools on the MCP server.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.